@@ -256,18 +256,18 @@ test_that("test xml files with XPath", {
 
     actual <- readtext("../data/xml/tei.xml",
                       text_field = "/d1:TEI/d1:text/d1:body//d1:p")#,
-                      # namespaces = c(tei = "http://www.tei-c.org/ns/1.0"))
+                      # namespaces = c(tei = "https://www.tei-c.org/ns/1.0"))
     expect_equal(texts(actual), expected)
 
 
     actual <- readtext("../data/xml/tei.xml", collapse = "P",
                        text_field = "/d1:TEI/d1:text/d1:body//d1:p")
-                       # namespaces = c(tei = "http://www.tei-c.org/ns/1.0"))
+                       # namespaces = c(tei = "https://www.tei-c.org/ns/1.0"))
     expect_equal(unname(texts(actual)), "The Pquick Pbrown Pfox")
 
     actual <- readtext("../data/xml/tei.xml", collapse = "P",
                       text_field = "/d1:TEI//*/text()")#,
-                      # namespaces = c(tei = "http://www.tei-c.org/ns/1.0"))
+                      # namespaces = c(tei = "https://www.tei-c.org/ns/1.0"))
     expect_equal(unname(texts(actual)), "Lorem Ipsum 1PSome PlacePAnywhere, USPNopePThe Pquick Pbrown PfoxPNope")
 
 })
@@ -511,12 +511,12 @@ test_that("Test function to list files", {
 test_that("Test function to list files with remote sources", {
     skip_on_cran()
     expect_error(
-      readtext:::list_files("http://www.google.com/404.txt"),
+      readtext:::list_files("https://www.google.com/404.txt"),
       ".*404.*"
     )
     
     expect_equal(
-      dim(readtext("http://www.google.com/404.txt", ignore_missing_files = TRUE)),
+      dim(readtext("https://www.google.com/404.txt", ignore_missing_files = TRUE)),
       c(1,2)
     )
 })
@@ -563,7 +563,7 @@ test_that("text vectors have names of the files they come from by default (bug 2
 
 test_that("test globbed tar file",{
     skip_on_cran()
-    skip_on_travis()
+    skip_on_os("linux")
     expect_equal(
         unname(texts(readtext("../data/tar/*"))),
         c("Lorem ipsum", "brown fox", "Dolor sit", "The quick")
@@ -581,7 +581,6 @@ test_that("test html file",{
 
 })
 
-
 test_that("test malformed html file",{
     skip_on_os("windows")
     expected <- c("The quick brown fox \n    \njumps over the lazy dog")
@@ -592,21 +591,17 @@ test_that("test malformed html file",{
     )
 })
 
-
 test_that("test for pdf file", {
     skip_on_os("windows")
-    skip_on_travis()
-    expected <- c(test.pdf = "The quick brown fox jumps over the lazy dog\n                                     1\n")
-    expect_equal(
-        texts(readtext("../data/pdf/test.pdf")),
-        expected
+    expect_output(
+        cat(texts(readtext("../data/pdf/test.pdf"))),
+        "The quick brown fox jumps over the lazy dog\n" 
     )
 })
 
 test_that("test for odt file", {
 	expected <- c("The quick brown fox jumps over the lazy dog")
 	names(expected) <- "test.odt"
-	
 	expect_equal(
 		texts(readtext("../data/odt/test.odt")),
 		expected
@@ -614,7 +609,6 @@ test_that("test for odt file", {
 	
 })
 
-
 test_that("test for docx file", {
     expected <- c("The quick brown fox jumps over the lazy dog")
     names(expected) <- "test.docx"
@@ -623,11 +617,8 @@ test_that("test for docx file", {
         texts(readtext("../data/docx/test.docx")),
         expected
     )
-
 })
 
-
-
 test_that("test for doc file", {
     skip_on_os("windows")  
     expected <- paste(rep(c("The quick brown fox jumps over the lazy dog."), 10), collapse = " ")
@@ -646,7 +637,7 @@ test_that("test for doc file", {
 
 test_that("test json files", {
     skip_on_cran()
-    skip_on_travis()
+    skip_on_os("linux")
     expect_equal(
         unname(texts(readtext("../data/json/test*json", text_field = "text"))),
         c("Lorem ipsum", "Dolor sit", "The quick", "brown fox", "Now is the winter")
@@ -716,7 +707,7 @@ if (.Platform$OS.type == "unix") {
 context("Loading a corpus from a tar archive")
 test_that("A single-level tar file containing txt files can be loaded",{
     skip_on_cran()
-    skip_on_travis()
+    skip_on_os("linux")
     expect_equal(
         unname(texts(readtext("../data/tar/test.tar"))),
         c("Lorem ipsum", "brown fox", "Dolor sit", "The quick")
@@ -726,7 +717,7 @@ test_that("A single-level tar file containing txt files can be loaded",{
 context("Loading a corpus from a gzipped tar archive")
 test_that("A single-level tar.gz file containing txt files can be loaded",{
     skip_on_cran()
-    skip_on_travis()
+    skip_on_os("linux")
     expect_equal(
         unname(texts(readtext("../data/targz/test.tar.gz"))),
         c("Lorem ipsum", "brown fox", "Dolor sit", "The quick")
@@ -736,7 +727,7 @@ test_that("A single-level tar.gz file containing txt files can be loaded",{
 context("Loading a corpus from a bzipped tar archive")
 test_that("A single-level tar.bz file containing txt files can be loaded",{
     skip_on_cran()
-    skip_on_travis()
+    skip_on_os("linux")
     skip_on_os("windows")
     expect_equal(
         unname(texts(readtext("../data/tarbz/test.tar.bz"))),
